/*********************************
 Enable WebPresence
 (c) 1999 Jeremy Wise
 GnomeICU
**********************************/

/*** GnomeICU header files ***/
#include "common.h"

/*** Global functions ***/
void icq_sendwebpresence( void )
{
	net_icq_pak pak;

#ifdef TRACE_FUNCTION
	g_print( "icq_sendwebpresence\n" );
#endif

	Word_2_Chars( pak.head.ver, ICQ_VER );
	Word_2_Chars( pak.head.cmd, CMD_META_USER );
	Word_2_Chars( pak.head.seq, seq_num++ );
	DW_2_Chars( pak.head.UIN, our_info->uin );

	pak.data[0] = 0x24;
	pak.data[1] = 0x04;
	pak.data[2] = !our_info->auth; /* 00=Require auth, 01=Auth not req'd */
	pak.data[3] = toggles->webpresence;
	pak.data[4] = 0x01; /* Publish IP */

	SOCKWRITE( &(pak.head.ver), 5 + sizeof( pak.head ) - 2, "CMD_META_USER(A/W/I)");
}
